<?php

/**
 * @file
 * Views integration hooks.
 */

/**
 * Implements hook_views_post_render().
 */
function user_blogs_views_post_render(&$view, &$output, &$cache) {
  // Add an appropriate menu-trail for the blog view.
  if ($view->name != 'user_blogs_listing') {
    return;
  }

  // Default trail is: Home >> Blogs
  $trail = array(
    array(
      'title' => t('Home'),
      'href' => '<front>',
      'localized_options' => array(),
      'type' => MENU_NORMAL_ITEM,
    ),
    array(
      'title' => t('Blogs'),
      'href' => 'blogs',
      'localized_options' => array(),
      'type' => MENU_NORMAL_ITEM,
    ),
  );

  // Add breadcrumb entries for the arguments.
  if (count($view->args)) {
    // Build a timestamp for the provided arguments.
    $date = (object) array(
      'year'  => isset($view->args[1]) ? $view->args[1] : date('Y'),
      'month' => isset($view->args[2]) ? $view->args[2] : date('n'),
      'day'   => isset($view->args[3]) ? $view->args[3] : date('j'),
    );
    $date = mktime(12, 0, 0, $date->month, $date->day, $date->year);
    // Add in our user to the breadcrumb before the dates.
    if (count($view->args) >= 0) {
      $trail[] = array(
        'title' => $view->args[0],
        'href' => "blogs/{$view->args[0]}",
        'localized_options' => array(),
        'type' => MENU_NORMAL_ITEM,
      );
    }
    // If there's a MONTH argument, add the year to the breadcrumb.
    if (isset($view->args[2])) {
      $trail[] = array(
        'title' => $view->args[1],
        'href' => "blogs/{$view->args[0]}/{$view->args[1]}",
        'localized_options' => array(),
        'type' => MENU_NORMAL_ITEM,
      );
    }
    // If there's a DAY argument, add the month to the breadcrumb.
    if (isset($view->args[3])) {
      // Translate the numeric month argument to a month name.
      $month = date('F', $date);
      $trail[] = array(
        'title' => $month,
        'href' => "blogs/{$view->args[0]}/{$view->args[1]}/{$view->args[2]}",
        'localized_options' => array(),
        'type' => MENU_NORMAL_ITEM,
      );
    }
  }

  // Views tries to set the breadcrumb. Reset it so it's controlled by the
  // active menu trail instead.
  drupal_static_reset('drupal_set_breadcrumb');
  menu_set_active_trail($trail);
}
